[PATCH] D49405: Change the cap on the amount of padding for each vtable to 32-byte (previously it was 128-byte)

Zhaomo Yang via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Mon Jul 16 16:06:00 PDT 2018


zhaomo updated this revision to Diff 155782.
zhaomo added a comment.
Herald added a subscriber: llvm-commits.

- removed .arcconfig


Repository:
  rL LLVM

https://reviews.llvm.org/D49405

Files:
  llvm/lib/Transforms/IPO/LowerTypeTests.cpp


Index: llvm/lib/Transforms/IPO/LowerTypeTests.cpp
===================================================================
--- llvm/lib/Transforms/IPO/LowerTypeTests.cpp
+++ llvm/lib/Transforms/IPO/LowerTypeTests.cpp
@@ -771,10 +771,10 @@
     // Compute the amount of padding required.
     uint64_t Padding = NextPowerOf2(InitSize - 1) - InitSize;
 
     // Cap at 128 was found experimentally to have a good data/instruction
     // overhead tradeoff.
-    if (Padding > 128)
-      Padding = alignTo(InitSize, 128) - InitSize;
+    if (Padding > 32)
+      Padding = alignTo(InitSize, 32) - InitSize;
 
     GlobalInits.push_back(
         ConstantAggregateZero::get(ArrayType::get(Int8Ty, Padding)));


-------------- next part --------------
@@ -771,10 +771,10 @@
     uint64_t Padding = NextPowerOf2(InitSize - 1) - InitSize;
 
-    // Cap at 128 was found experimentally to have a good data/instruction
+    // Cap at 32 was found experimentally to have a good data/instruction
     // overhead tradeoff.
A non-text attachment was scrubbed...
Name: D49405.155782.patch
Type: text/x-patch
Size: 776 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20180716/4a87390a/attachment.bin>


More information about the llvm-commits mailing list